"""
Type annotations for guardduty service client.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html)

Usage::

    ```python
    import boto3
    from mypy_boto3_guardduty import GuardDutyClient

    client: GuardDutyClient = boto3.client("guardduty")
    ```
"""
import sys
from typing import Any, Dict, List, Type, overload

from botocore.client import ClientMeta

from mypy_boto3_guardduty.literals import (
    Feedback,
    FilterAction,
    FindingPublishingFrequency,
    IpSetFormat,
    ThreatIntelSetFormat,
    UsageStatisticType,
)
from mypy_boto3_guardduty.paginator import (
    ListDetectorsPaginator,
    ListFiltersPaginator,
    ListFindingsPaginator,
    ListInvitationsPaginator,
    ListIPSetsPaginator,
    ListMembersPaginator,
    ListOrganizationAdminAccountsPaginator,
    ListThreatIntelSetsPaginator,
)
from mypy_boto3_guardduty.type_defs import (
    AccountDetailTypeDef,
    CreateDetectorResponseTypeDef,
    CreateFilterResponseTypeDef,
    CreateIPSetResponseTypeDef,
    CreateMembersResponseTypeDef,
    CreatePublishingDestinationResponseTypeDef,
    CreateThreatIntelSetResponseTypeDef,
    DataSourceConfigurationsTypeDef,
    DeclineInvitationsResponseTypeDef,
    DeleteInvitationsResponseTypeDef,
    DeleteMembersResponseTypeDef,
    DescribeOrganizationConfigurationResponseTypeDef,
    DescribePublishingDestinationResponseTypeDef,
    DestinationPropertiesTypeDef,
    DisassociateMembersResponseTypeDef,
    FindingCriteriaTypeDef,
    GetDetectorResponseTypeDef,
    GetFilterResponseTypeDef,
    GetFindingsResponseTypeDef,
    GetFindingsStatisticsResponseTypeDef,
    GetInvitationsCountResponseTypeDef,
    GetIPSetResponseTypeDef,
    GetMasterAccountResponseTypeDef,
    GetMemberDetectorsResponseTypeDef,
    GetMembersResponseTypeDef,
    GetThreatIntelSetResponseTypeDef,
    GetUsageStatisticsResponseTypeDef,
    InviteMembersResponseTypeDef,
    ListDetectorsResponseTypeDef,
    ListFiltersResponseTypeDef,
    ListFindingsResponseTypeDef,
    ListInvitationsResponseTypeDef,
    ListIPSetsResponseTypeDef,
    ListMembersResponseTypeDef,
    ListOrganizationAdminAccountsResponseTypeDef,
    ListPublishingDestinationsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListThreatIntelSetsResponseTypeDef,
    OrganizationDataSourceConfigurationsTypeDef,
    SortCriteriaTypeDef,
    StartMonitoringMembersResponseTypeDef,
    StopMonitoringMembersResponseTypeDef,
    UpdateFilterResponseTypeDef,
    UpdateMemberDetectorsResponseTypeDef,
    UsageCriteriaTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = ("GuardDutyClient",)

class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str
    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str

class Exceptions:
    BadRequestException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    InternalServerErrorException: Type[BotocoreClientError]

class GuardDutyClient:
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client)
    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html)
    """

    meta: ClientMeta
    exceptions: Exceptions
    def accept_invitation(
        self, DetectorId: str, MasterId: str, InvitationId: str
    ) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.accept_invitation)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#accept-invitation)
        """
    def archive_findings(self, DetectorId: str, FindingIds: List[str]) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.archive_findings)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#archive-findings)
        """
    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.can_paginate)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#can-paginate)
        """
    def create_detector(
        self,
        Enable: bool,
        ClientToken: str = None,
        FindingPublishingFrequency: FindingPublishingFrequency = None,
        DataSources: DataSourceConfigurationsTypeDef = None,
        Tags: Dict[str, str] = None,
    ) -> CreateDetectorResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.create_detector)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#create-detector)
        """
    def create_filter(
        self,
        DetectorId: str,
        Name: str,
        FindingCriteria: "FindingCriteriaTypeDef",
        Description: str = None,
        Action: FilterAction = None,
        Rank: int = None,
        ClientToken: str = None,
        Tags: Dict[str, str] = None,
    ) -> CreateFilterResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.create_filter)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#create-filter)
        """
    def create_ip_set(
        self,
        DetectorId: str,
        Name: str,
        Format: IpSetFormat,
        Location: str,
        Activate: bool,
        ClientToken: str = None,
        Tags: Dict[str, str] = None,
    ) -> CreateIPSetResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.create_ip_set)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#create-ip-set)
        """
    def create_members(
        self, DetectorId: str, AccountDetails: List[AccountDetailTypeDef]
    ) -> CreateMembersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.create_members)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#create-members)
        """
    def create_publishing_destination(
        self,
        DetectorId: str,
        DestinationType: Literal["S3"],
        DestinationProperties: "DestinationPropertiesTypeDef",
        ClientToken: str = None,
    ) -> CreatePublishingDestinationResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.create_publishing_destination)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#create-publishing-destination)
        """
    def create_sample_findings(
        self, DetectorId: str, FindingTypes: List[str] = None
    ) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.create_sample_findings)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#create-sample-findings)
        """
    def create_threat_intel_set(
        self,
        DetectorId: str,
        Name: str,
        Format: ThreatIntelSetFormat,
        Location: str,
        Activate: bool,
        ClientToken: str = None,
        Tags: Dict[str, str] = None,
    ) -> CreateThreatIntelSetResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.create_threat_intel_set)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#create-threat-intel-set)
        """
    def decline_invitations(self, AccountIds: List[str]) -> DeclineInvitationsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.decline_invitations)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#decline-invitations)
        """
    def delete_detector(self, DetectorId: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.delete_detector)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#delete-detector)
        """
    def delete_filter(self, DetectorId: str, FilterName: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.delete_filter)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#delete-filter)
        """
    def delete_invitations(self, AccountIds: List[str]) -> DeleteInvitationsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.delete_invitations)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#delete-invitations)
        """
    def delete_ip_set(self, DetectorId: str, IpSetId: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.delete_ip_set)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#delete-ip-set)
        """
    def delete_members(
        self, DetectorId: str, AccountIds: List[str]
    ) -> DeleteMembersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.delete_members)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#delete-members)
        """
    def delete_publishing_destination(self, DetectorId: str, DestinationId: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.delete_publishing_destination)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#delete-publishing-destination)
        """
    def delete_threat_intel_set(self, DetectorId: str, ThreatIntelSetId: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.delete_threat_intel_set)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#delete-threat-intel-set)
        """
    def describe_organization_configuration(
        self, DetectorId: str
    ) -> DescribeOrganizationConfigurationResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.describe_organization_configuration)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#describe-organization-configuration)
        """
    def describe_publishing_destination(
        self, DetectorId: str, DestinationId: str
    ) -> DescribePublishingDestinationResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.describe_publishing_destination)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#describe-publishing-destination)
        """
    def disable_organization_admin_account(self, AdminAccountId: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.disable_organization_admin_account)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#disable-organization-admin-account)
        """
    def disassociate_from_master_account(self, DetectorId: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.disassociate_from_master_account)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#disassociate-from-master-account)
        """
    def disassociate_members(
        self, DetectorId: str, AccountIds: List[str]
    ) -> DisassociateMembersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.disassociate_members)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#disassociate-members)
        """
    def enable_organization_admin_account(self, AdminAccountId: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.enable_organization_admin_account)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#enable-organization-admin-account)
        """
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.generate_presigned_url)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#generate-presigned-url)
        """
    def get_detector(self, DetectorId: str) -> GetDetectorResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_detector)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-detector)
        """
    def get_filter(self, DetectorId: str, FilterName: str) -> GetFilterResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_filter)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-filter)
        """
    def get_findings(
        self, DetectorId: str, FindingIds: List[str], SortCriteria: SortCriteriaTypeDef = None
    ) -> GetFindingsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_findings)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-findings)
        """
    def get_findings_statistics(
        self,
        DetectorId: str,
        FindingStatisticTypes: List[Literal["COUNT_BY_SEVERITY"]],
        FindingCriteria: "FindingCriteriaTypeDef" = None,
    ) -> GetFindingsStatisticsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_findings_statistics)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-findings-statistics)
        """
    def get_invitations_count(self) -> GetInvitationsCountResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_invitations_count)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-invitations-count)
        """
    def get_ip_set(self, DetectorId: str, IpSetId: str) -> GetIPSetResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_ip_set)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-ip-set)
        """
    def get_master_account(self, DetectorId: str) -> GetMasterAccountResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_master_account)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-master-account)
        """
    def get_member_detectors(
        self, DetectorId: str, AccountIds: List[str]
    ) -> GetMemberDetectorsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_member_detectors)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-member-detectors)
        """
    def get_members(self, DetectorId: str, AccountIds: List[str]) -> GetMembersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_members)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-members)
        """
    def get_threat_intel_set(
        self, DetectorId: str, ThreatIntelSetId: str
    ) -> GetThreatIntelSetResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_threat_intel_set)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-threat-intel-set)
        """
    def get_usage_statistics(
        self,
        DetectorId: str,
        UsageStatisticType: UsageStatisticType,
        UsageCriteria: UsageCriteriaTypeDef,
        Unit: str = None,
        MaxResults: int = None,
        NextToken: str = None,
    ) -> GetUsageStatisticsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.get_usage_statistics)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#get-usage-statistics)
        """
    def invite_members(
        self,
        DetectorId: str,
        AccountIds: List[str],
        DisableEmailNotification: bool = None,
        Message: str = None,
    ) -> InviteMembersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.invite_members)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#invite-members)
        """
    def list_detectors(
        self, MaxResults: int = None, NextToken: str = None
    ) -> ListDetectorsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_detectors)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-detectors)
        """
    def list_filters(
        self, DetectorId: str, MaxResults: int = None, NextToken: str = None
    ) -> ListFiltersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_filters)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-filters)
        """
    def list_findings(
        self,
        DetectorId: str,
        FindingCriteria: "FindingCriteriaTypeDef" = None,
        SortCriteria: SortCriteriaTypeDef = None,
        MaxResults: int = None,
        NextToken: str = None,
    ) -> ListFindingsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_findings)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-findings)
        """
    def list_invitations(
        self, MaxResults: int = None, NextToken: str = None
    ) -> ListInvitationsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_invitations)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-invitations)
        """
    def list_ip_sets(
        self, DetectorId: str, MaxResults: int = None, NextToken: str = None
    ) -> ListIPSetsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_ip_sets)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-ip-sets)
        """
    def list_members(
        self,
        DetectorId: str,
        MaxResults: int = None,
        NextToken: str = None,
        OnlyAssociated: str = None,
    ) -> ListMembersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_members)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-members)
        """
    def list_organization_admin_accounts(
        self, MaxResults: int = None, NextToken: str = None
    ) -> ListOrganizationAdminAccountsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_organization_admin_accounts)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-organization-admin-accounts)
        """
    def list_publishing_destinations(
        self, DetectorId: str, MaxResults: int = None, NextToken: str = None
    ) -> ListPublishingDestinationsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_publishing_destinations)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-publishing-destinations)
        """
    def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_tags_for_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-tags-for-resource)
        """
    def list_threat_intel_sets(
        self, DetectorId: str, MaxResults: int = None, NextToken: str = None
    ) -> ListThreatIntelSetsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.list_threat_intel_sets)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#list-threat-intel-sets)
        """
    def start_monitoring_members(
        self, DetectorId: str, AccountIds: List[str]
    ) -> StartMonitoringMembersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.start_monitoring_members)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#start-monitoring-members)
        """
    def stop_monitoring_members(
        self, DetectorId: str, AccountIds: List[str]
    ) -> StopMonitoringMembersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.stop_monitoring_members)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#stop-monitoring-members)
        """
    def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.tag_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#tag-resource)
        """
    def unarchive_findings(self, DetectorId: str, FindingIds: List[str]) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.unarchive_findings)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#unarchive-findings)
        """
    def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.untag_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#untag-resource)
        """
    def update_detector(
        self,
        DetectorId: str,
        Enable: bool = None,
        FindingPublishingFrequency: FindingPublishingFrequency = None,
        DataSources: DataSourceConfigurationsTypeDef = None,
    ) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.update_detector)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#update-detector)
        """
    def update_filter(
        self,
        DetectorId: str,
        FilterName: str,
        Description: str = None,
        Action: FilterAction = None,
        Rank: int = None,
        FindingCriteria: "FindingCriteriaTypeDef" = None,
    ) -> UpdateFilterResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.update_filter)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#update-filter)
        """
    def update_findings_feedback(
        self, DetectorId: str, FindingIds: List[str], Feedback: Feedback, Comments: str = None
    ) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.update_findings_feedback)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#update-findings-feedback)
        """
    def update_ip_set(
        self,
        DetectorId: str,
        IpSetId: str,
        Name: str = None,
        Location: str = None,
        Activate: bool = None,
    ) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.update_ip_set)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#update-ip-set)
        """
    def update_member_detectors(
        self,
        DetectorId: str,
        AccountIds: List[str],
        DataSources: DataSourceConfigurationsTypeDef = None,
    ) -> UpdateMemberDetectorsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.update_member_detectors)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#update-member-detectors)
        """
    def update_organization_configuration(
        self,
        DetectorId: str,
        AutoEnable: bool,
        DataSources: OrganizationDataSourceConfigurationsTypeDef = None,
    ) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.update_organization_configuration)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#update-organization-configuration)
        """
    def update_publishing_destination(
        self,
        DetectorId: str,
        DestinationId: str,
        DestinationProperties: "DestinationPropertiesTypeDef" = None,
    ) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.update_publishing_destination)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#update-publishing-destination)
        """
    def update_threat_intel_set(
        self,
        DetectorId: str,
        ThreatIntelSetId: str,
        Name: str = None,
        Location: str = None,
        Activate: bool = None,
    ) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Client.update_threat_intel_set)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/client.html#update-threat-intel-set)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_detectors"]) -> ListDetectorsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Paginator.ListDetectors)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/paginators.html#listdetectorspaginator)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_filters"]) -> ListFiltersPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Paginator.ListFilters)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/paginators.html#listfilterspaginator)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_findings"]) -> ListFindingsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Paginator.ListFindings)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/paginators.html#listfindingspaginator)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_ip_sets"]) -> ListIPSetsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Paginator.ListIPSets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/paginators.html#listipsetspaginator)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_invitations"]
    ) -> ListInvitationsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Paginator.ListInvitations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/paginators.html#listinvitationspaginator)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_members"]) -> ListMembersPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Paginator.ListMembers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/paginators.html#listmemberspaginator)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_organization_admin_accounts"]
    ) -> ListOrganizationAdminAccountsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Paginator.ListOrganizationAdminAccounts)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/paginators.html#listorganizationadminaccountspaginator)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_threat_intel_sets"]
    ) -> ListThreatIntelSetsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/guardduty.html#GuardDuty.Paginator.ListThreatIntelSets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/paginators.html#listthreatintelsetspaginator)
        """



"""
Type annotations for guardduty service literal definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/literals.html)

Usage::

    ```python
    from mypy_boto3_guardduty.literals import AdminStatus

    data: AdminStatus = "DISABLE_IN_PROGRESS"
    ```
"""
import sys

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = (
    "AdminStatus",
    "DataSource",
    "DataSourceStatus",
    "DestinationType",
    "DetectorStatus",
    "Feedback",
    "FilterAction",
    "FindingPublishingFrequency",
    "FindingStatisticType",
    "IpSetFormat",
    "IpSetStatus",
    "ListDetectorsPaginatorName",
    "ListFiltersPaginatorName",
    "ListFindingsPaginatorName",
    "ListIPSetsPaginatorName",
    "ListInvitationsPaginatorName",
    "ListMembersPaginatorName",
    "ListOrganizationAdminAccountsPaginatorName",
    "ListThreatIntelSetsPaginatorName",
    "OrderBy",
    "PublishingStatus",
    "ThreatIntelSetFormat",
    "ThreatIntelSetStatus",
    "UsageStatisticType",
)

AdminStatus = Literal["DISABLE_IN_PROGRESS", "ENABLED"]
DataSource = Literal["CLOUD_TRAIL", "DNS_LOGS", "FLOW_LOGS", "S3_LOGS"]
DataSourceStatus = Literal["DISABLED", "ENABLED"]
DestinationType = Literal["S3"]
DetectorStatus = Literal["DISABLED", "ENABLED"]
Feedback = Literal["NOT_USEFUL", "USEFUL"]
FilterAction = Literal["ARCHIVE", "NOOP"]
FindingPublishingFrequency = Literal["FIFTEEN_MINUTES", "ONE_HOUR", "SIX_HOURS"]
FindingStatisticType = Literal["COUNT_BY_SEVERITY"]
IpSetFormat = Literal["ALIEN_VAULT", "FIRE_EYE", "OTX_CSV", "PROOF_POINT", "STIX", "TXT"]
IpSetStatus = Literal[
    "ACTIVATING", "ACTIVE", "DEACTIVATING", "DELETED", "DELETE_PENDING", "ERROR", "INACTIVE"
]
ListDetectorsPaginatorName = Literal["list_detectors"]
ListFiltersPaginatorName = Literal["list_filters"]
ListFindingsPaginatorName = Literal["list_findings"]
ListIPSetsPaginatorName = Literal["list_ip_sets"]
ListInvitationsPaginatorName = Literal["list_invitations"]
ListMembersPaginatorName = Literal["list_members"]
ListOrganizationAdminAccountsPaginatorName = Literal["list_organization_admin_accounts"]
ListThreatIntelSetsPaginatorName = Literal["list_threat_intel_sets"]
OrderBy = Literal["ASC", "DESC"]
PublishingStatus = Literal[
    "PENDING_VERIFICATION", "PUBLISHING", "STOPPED", "UNABLE_TO_PUBLISH_FIX_DESTINATION_PROPERTY"
]
ThreatIntelSetFormat = Literal["ALIEN_VAULT", "FIRE_EYE", "OTX_CSV", "PROOF_POINT", "STIX", "TXT"]
ThreatIntelSetStatus = Literal[
    "ACTIVATING", "ACTIVE", "DEACTIVATING", "DELETED", "DELETE_PENDING", "ERROR", "INACTIVE"
]
UsageStatisticType = Literal[
    "SUM_BY_ACCOUNT", "SUM_BY_DATA_SOURCE", "SUM_BY_RESOURCE", "TOP_RESOURCES"
]



"""
Type annotations for guardduty service type definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_guardduty/type_defs.html)

Usage::

    ```python
    from mypy_boto3_guardduty.type_defs import AccessControlListTypeDef

    data: AccessControlListTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Dict, List

from mypy_boto3_guardduty.literals import (
    AdminStatus,
    DataSource,
    DataSourceStatus,
    DetectorStatus,
    FilterAction,
    FindingPublishingFrequency,
    IpSetFormat,
    IpSetStatus,
    OrderBy,
    PublishingStatus,
    ThreatIntelSetFormat,
    ThreatIntelSetStatus,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "AccessControlListTypeDef",
    "AccessKeyDetailsTypeDef",
    "AccountDetailTypeDef",
    "AccountLevelPermissionsTypeDef",
    "ActionTypeDef",
    "AdminAccountTypeDef",
    "AwsApiCallActionTypeDef",
    "BlockPublicAccessTypeDef",
    "BucketLevelPermissionsTypeDef",
    "BucketPolicyTypeDef",
    "CityTypeDef",
    "CloudTrailConfigurationResultTypeDef",
    "ConditionTypeDef",
    "CountryTypeDef",
    "CreateDetectorResponseTypeDef",
    "CreateFilterResponseTypeDef",
    "CreateIPSetResponseTypeDef",
    "CreateMembersResponseTypeDef",
    "CreatePublishingDestinationResponseTypeDef",
    "CreateThreatIntelSetResponseTypeDef",
    "DNSLogsConfigurationResultTypeDef",
    "DataSourceConfigurationsResultTypeDef",
    "DataSourceConfigurationsTypeDef",
    "DeclineInvitationsResponseTypeDef",
    "DefaultServerSideEncryptionTypeDef",
    "DeleteInvitationsResponseTypeDef",
    "DeleteMembersResponseTypeDef",
    "DescribeOrganizationConfigurationResponseTypeDef",
    "DescribePublishingDestinationResponseTypeDef",
    "DestinationPropertiesTypeDef",
    "DestinationTypeDef",
    "DisassociateMembersResponseTypeDef",
    "DnsRequestActionTypeDef",
    "DomainDetailsTypeDef",
    "EvidenceTypeDef",
    "FindingCriteriaTypeDef",
    "FindingStatisticsTypeDef",
    "FindingTypeDef",
    "FlowLogsConfigurationResultTypeDef",
    "GeoLocationTypeDef",
    "GetDetectorResponseTypeDef",
    "GetFilterResponseTypeDef",
    "GetFindingsResponseTypeDef",
    "GetFindingsStatisticsResponseTypeDef",
    "GetIPSetResponseTypeDef",
    "GetInvitationsCountResponseTypeDef",
    "GetMasterAccountResponseTypeDef",
    "GetMemberDetectorsResponseTypeDef",
    "GetMembersResponseTypeDef",
    "GetThreatIntelSetResponseTypeDef",
    "GetUsageStatisticsResponseTypeDef",
    "IamInstanceProfileTypeDef",
    "InstanceDetailsTypeDef",
    "InvitationTypeDef",
    "InviteMembersResponseTypeDef",
    "ListDetectorsResponseTypeDef",
    "ListFiltersResponseTypeDef",
    "ListFindingsResponseTypeDef",
    "ListIPSetsResponseTypeDef",
    "ListInvitationsResponseTypeDef",
    "ListMembersResponseTypeDef",
    "ListOrganizationAdminAccountsResponseTypeDef",
    "ListPublishingDestinationsResponseTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "ListThreatIntelSetsResponseTypeDef",
    "LocalIpDetailsTypeDef",
    "LocalPortDetailsTypeDef",
    "MasterTypeDef",
    "MemberDataSourceConfigurationTypeDef",
    "MemberTypeDef",
    "NetworkConnectionActionTypeDef",
    "NetworkInterfaceTypeDef",
    "OrganizationDataSourceConfigurationsResultTypeDef",
    "OrganizationDataSourceConfigurationsTypeDef",
    "OrganizationS3LogsConfigurationResultTypeDef",
    "OrganizationS3LogsConfigurationTypeDef",
    "OrganizationTypeDef",
    "OwnerTypeDef",
    "PaginatorConfigTypeDef",
    "PermissionConfigurationTypeDef",
    "PortProbeActionTypeDef",
    "PortProbeDetailTypeDef",
    "PrivateIpAddressDetailsTypeDef",
    "ProductCodeTypeDef",
    "PublicAccessTypeDef",
    "RemoteIpDetailsTypeDef",
    "RemotePortDetailsTypeDef",
    "ResourceTypeDef",
    "S3BucketDetailTypeDef",
    "S3LogsConfigurationResultTypeDef",
    "S3LogsConfigurationTypeDef",
    "SecurityGroupTypeDef",
    "ServiceTypeDef",
    "SortCriteriaTypeDef",
    "StartMonitoringMembersResponseTypeDef",
    "StopMonitoringMembersResponseTypeDef",
    "TagTypeDef",
    "ThreatIntelligenceDetailTypeDef",
    "TotalTypeDef",
    "UnprocessedAccountTypeDef",
    "UpdateFilterResponseTypeDef",
    "UpdateMemberDetectorsResponseTypeDef",
    "UsageAccountResultTypeDef",
    "UsageCriteriaTypeDef",
    "UsageDataSourceResultTypeDef",
    "UsageResourceResultTypeDef",
    "UsageStatisticsTypeDef",
)


class AccessControlListTypeDef(TypedDict, total=False):
    AllowsPublicReadAccess: bool
    AllowsPublicWriteAccess: bool


class AccessKeyDetailsTypeDef(TypedDict, total=False):
    AccessKeyId: str
    PrincipalId: str
    UserName: str
    UserType: str


class AccountDetailTypeDef(TypedDict):
    AccountId: str
    Email: str


class AccountLevelPermissionsTypeDef(TypedDict, total=False):
    BlockPublicAccess: "BlockPublicAccessTypeDef"


class ActionTypeDef(TypedDict, total=False):
    ActionType: str
    AwsApiCallAction: "AwsApiCallActionTypeDef"
    DnsRequestAction: "DnsRequestActionTypeDef"
    NetworkConnectionAction: "NetworkConnectionActionTypeDef"
    PortProbeAction: "PortProbeActionTypeDef"


class AdminAccountTypeDef(TypedDict, total=False):
    AdminAccountId: str
    AdminStatus: AdminStatus


class AwsApiCallActionTypeDef(TypedDict, total=False):
    Api: str
    CallerType: str
    DomainDetails: "DomainDetailsTypeDef"
    ErrorCode: str
    RemoteIpDetails: "RemoteIpDetailsTypeDef"
    ServiceName: str


class BlockPublicAccessTypeDef(TypedDict, total=False):
    IgnorePublicAcls: bool
    RestrictPublicBuckets: bool
    BlockPublicAcls: bool
    BlockPublicPolicy: bool


class BucketLevelPermissionsTypeDef(TypedDict, total=False):
    AccessControlList: "AccessControlListTypeDef"
    BucketPolicy: "BucketPolicyTypeDef"
    BlockPublicAccess: "BlockPublicAccessTypeDef"


class BucketPolicyTypeDef(TypedDict, total=False):
    AllowsPublicReadAccess: bool
    AllowsPublicWriteAccess: bool


class CityTypeDef(TypedDict, total=False):
    CityName: str


class CloudTrailConfigurationResultTypeDef(TypedDict):
    Status: DataSourceStatus


class ConditionTypeDef(TypedDict, total=False):
    Eq: List[str]
    Neq: List[str]
    Gt: int
    Gte: int
    Lt: int
    Lte: int
    Equals: List[str]
    NotEquals: List[str]
    GreaterThan: int
    GreaterThanOrEqual: int
    LessThan: int
    LessThanOrEqual: int


class CountryTypeDef(TypedDict, total=False):
    CountryCode: str
    CountryName: str


class CreateDetectorResponseTypeDef(TypedDict, total=False):
    DetectorId: str


class CreateFilterResponseTypeDef(TypedDict):
    Name: str


class CreateIPSetResponseTypeDef(TypedDict):
    IpSetId: str


class CreateMembersResponseTypeDef(TypedDict):
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class CreatePublishingDestinationResponseTypeDef(TypedDict):
    DestinationId: str


class CreateThreatIntelSetResponseTypeDef(TypedDict):
    ThreatIntelSetId: str


class DNSLogsConfigurationResultTypeDef(TypedDict):
    Status: DataSourceStatus


class DataSourceConfigurationsResultTypeDef(TypedDict):
    CloudTrail: "CloudTrailConfigurationResultTypeDef"
    DNSLogs: "DNSLogsConfigurationResultTypeDef"
    FlowLogs: "FlowLogsConfigurationResultTypeDef"
    S3Logs: "S3LogsConfigurationResultTypeDef"


class DataSourceConfigurationsTypeDef(TypedDict, total=False):
    S3Logs: "S3LogsConfigurationTypeDef"


class DeclineInvitationsResponseTypeDef(TypedDict):
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class DefaultServerSideEncryptionTypeDef(TypedDict, total=False):
    EncryptionType: str
    KmsMasterKeyArn: str


class DeleteInvitationsResponseTypeDef(TypedDict):
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class DeleteMembersResponseTypeDef(TypedDict):
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class _RequiredDescribeOrganizationConfigurationResponseTypeDef(TypedDict):
    AutoEnable: bool
    MemberAccountLimitReached: bool


class DescribeOrganizationConfigurationResponseTypeDef(
    _RequiredDescribeOrganizationConfigurationResponseTypeDef, total=False
):
    DataSources: "OrganizationDataSourceConfigurationsResultTypeDef"


class DescribePublishingDestinationResponseTypeDef(TypedDict):
    DestinationId: str
    DestinationType: Literal["S3"]
    Status: PublishingStatus
    PublishingFailureStartTimestamp: int
    DestinationProperties: "DestinationPropertiesTypeDef"


class DestinationPropertiesTypeDef(TypedDict, total=False):
    DestinationArn: str
    KmsKeyArn: str


class DestinationTypeDef(TypedDict):
    DestinationId: str
    DestinationType: Literal["S3"]
    Status: PublishingStatus


class DisassociateMembersResponseTypeDef(TypedDict):
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class DnsRequestActionTypeDef(TypedDict, total=False):
    Domain: str


class DomainDetailsTypeDef(TypedDict, total=False):
    Domain: str


class EvidenceTypeDef(TypedDict, total=False):
    ThreatIntelligenceDetails: List["ThreatIntelligenceDetailTypeDef"]


class FindingCriteriaTypeDef(TypedDict, total=False):
    Criterion: Dict[str, "ConditionTypeDef"]


class FindingStatisticsTypeDef(TypedDict, total=False):
    CountBySeverity: Dict[str, int]


_RequiredFindingTypeDef = TypedDict(
    "_RequiredFindingTypeDef",
    {
        "AccountId": str,
        "Arn": str,
        "CreatedAt": str,
        "Id": str,
        "Region": str,
        "Resource": "ResourceTypeDef",
        "SchemaVersion": str,
        "Severity": float,
        "Type": str,
        "UpdatedAt": str,
    },
)
_OptionalFindingTypeDef = TypedDict(
    "_OptionalFindingTypeDef",
    {
        "Confidence": float,
        "Description": str,
        "Partition": str,
        "Service": "ServiceTypeDef",
        "Title": str,
    },
    total=False,
)


class FindingTypeDef(_RequiredFindingTypeDef, _OptionalFindingTypeDef):
    pass


class FlowLogsConfigurationResultTypeDef(TypedDict):
    Status: DataSourceStatus


class GeoLocationTypeDef(TypedDict, total=False):
    Lat: float
    Lon: float


class _RequiredGetDetectorResponseTypeDef(TypedDict):
    ServiceRole: str
    Status: DetectorStatus


class GetDetectorResponseTypeDef(_RequiredGetDetectorResponseTypeDef, total=False):
    CreatedAt: str
    FindingPublishingFrequency: FindingPublishingFrequency
    UpdatedAt: str
    DataSources: "DataSourceConfigurationsResultTypeDef"
    Tags: Dict[str, str]


class _RequiredGetFilterResponseTypeDef(TypedDict):
    Name: str
    Action: FilterAction
    FindingCriteria: "FindingCriteriaTypeDef"


class GetFilterResponseTypeDef(_RequiredGetFilterResponseTypeDef, total=False):
    Description: str
    Rank: int
    Tags: Dict[str, str]


class GetFindingsResponseTypeDef(TypedDict):
    Findings: List["FindingTypeDef"]


class GetFindingsStatisticsResponseTypeDef(TypedDict):
    FindingStatistics: "FindingStatisticsTypeDef"


class _RequiredGetIPSetResponseTypeDef(TypedDict):
    Name: str
    Format: IpSetFormat
    Location: str
    Status: IpSetStatus


class GetIPSetResponseTypeDef(_RequiredGetIPSetResponseTypeDef, total=False):
    Tags: Dict[str, str]


class GetInvitationsCountResponseTypeDef(TypedDict, total=False):
    InvitationsCount: int


class GetMasterAccountResponseTypeDef(TypedDict):
    Master: "MasterTypeDef"


class GetMemberDetectorsResponseTypeDef(TypedDict):
    MemberDataSourceConfigurations: List["MemberDataSourceConfigurationTypeDef"]
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class GetMembersResponseTypeDef(TypedDict):
    Members: List["MemberTypeDef"]
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class _RequiredGetThreatIntelSetResponseTypeDef(TypedDict):
    Name: str
    Format: ThreatIntelSetFormat
    Location: str
    Status: ThreatIntelSetStatus


class GetThreatIntelSetResponseTypeDef(_RequiredGetThreatIntelSetResponseTypeDef, total=False):
    Tags: Dict[str, str]


class GetUsageStatisticsResponseTypeDef(TypedDict, total=False):
    UsageStatistics: "UsageStatisticsTypeDef"
    NextToken: str


class IamInstanceProfileTypeDef(TypedDict, total=False):
    Arn: str
    Id: str


class InstanceDetailsTypeDef(TypedDict, total=False):
    AvailabilityZone: str
    IamInstanceProfile: "IamInstanceProfileTypeDef"
    ImageDescription: str
    ImageId: str
    InstanceId: str
    InstanceState: str
    InstanceType: str
    OutpostArn: str
    LaunchTime: str
    NetworkInterfaces: List["NetworkInterfaceTypeDef"]
    Platform: str
    ProductCodes: List["ProductCodeTypeDef"]
    Tags: List["TagTypeDef"]


class InvitationTypeDef(TypedDict, total=False):
    AccountId: str
    InvitationId: str
    RelationshipStatus: str
    InvitedAt: str


class InviteMembersResponseTypeDef(TypedDict):
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class _RequiredListDetectorsResponseTypeDef(TypedDict):
    DetectorIds: List[str]


class ListDetectorsResponseTypeDef(_RequiredListDetectorsResponseTypeDef, total=False):
    NextToken: str


class _RequiredListFiltersResponseTypeDef(TypedDict):
    FilterNames: List[str]


class ListFiltersResponseTypeDef(_RequiredListFiltersResponseTypeDef, total=False):
    NextToken: str


class _RequiredListFindingsResponseTypeDef(TypedDict):
    FindingIds: List[str]


class ListFindingsResponseTypeDef(_RequiredListFindingsResponseTypeDef, total=False):
    NextToken: str


class _RequiredListIPSetsResponseTypeDef(TypedDict):
    IpSetIds: List[str]


class ListIPSetsResponseTypeDef(_RequiredListIPSetsResponseTypeDef, total=False):
    NextToken: str


class ListInvitationsResponseTypeDef(TypedDict, total=False):
    Invitations: List["InvitationTypeDef"]
    NextToken: str


class ListMembersResponseTypeDef(TypedDict, total=False):
    Members: List["MemberTypeDef"]
    NextToken: str


class ListOrganizationAdminAccountsResponseTypeDef(TypedDict, total=False):
    AdminAccounts: List["AdminAccountTypeDef"]
    NextToken: str


class _RequiredListPublishingDestinationsResponseTypeDef(TypedDict):
    Destinations: List["DestinationTypeDef"]


class ListPublishingDestinationsResponseTypeDef(
    _RequiredListPublishingDestinationsResponseTypeDef, total=False
):
    NextToken: str


class ListTagsForResourceResponseTypeDef(TypedDict, total=False):
    Tags: Dict[str, str]


class _RequiredListThreatIntelSetsResponseTypeDef(TypedDict):
    ThreatIntelSetIds: List[str]


class ListThreatIntelSetsResponseTypeDef(_RequiredListThreatIntelSetsResponseTypeDef, total=False):
    NextToken: str


class LocalIpDetailsTypeDef(TypedDict, total=False):
    IpAddressV4: str


class LocalPortDetailsTypeDef(TypedDict, total=False):
    Port: int
    PortName: str


class MasterTypeDef(TypedDict, total=False):
    AccountId: str
    InvitationId: str
    RelationshipStatus: str
    InvitedAt: str


class MemberDataSourceConfigurationTypeDef(TypedDict):
    AccountId: str
    DataSources: "DataSourceConfigurationsResultTypeDef"


class _RequiredMemberTypeDef(TypedDict):
    AccountId: str
    MasterId: str
    Email: str
    RelationshipStatus: str
    UpdatedAt: str


class MemberTypeDef(_RequiredMemberTypeDef, total=False):
    DetectorId: str
    InvitedAt: str


NetworkConnectionActionTypeDef = TypedDict(
    "NetworkConnectionActionTypeDef",
    {
        "Blocked": bool,
        "ConnectionDirection": str,
        "LocalPortDetails": "LocalPortDetailsTypeDef",
        "Protocol": str,
        "LocalIpDetails": "LocalIpDetailsTypeDef",
        "RemoteIpDetails": "RemoteIpDetailsTypeDef",
        "RemotePortDetails": "RemotePortDetailsTypeDef",
    },
    total=False,
)


class NetworkInterfaceTypeDef(TypedDict, total=False):
    Ipv6Addresses: List[str]
    NetworkInterfaceId: str
    PrivateDnsName: str
    PrivateIpAddress: str
    PrivateIpAddresses: List["PrivateIpAddressDetailsTypeDef"]
    PublicDnsName: str
    PublicIp: str
    SecurityGroups: List["SecurityGroupTypeDef"]
    SubnetId: str
    VpcId: str


class OrganizationDataSourceConfigurationsResultTypeDef(TypedDict):
    S3Logs: "OrganizationS3LogsConfigurationResultTypeDef"


class OrganizationDataSourceConfigurationsTypeDef(TypedDict, total=False):
    S3Logs: "OrganizationS3LogsConfigurationTypeDef"


class OrganizationS3LogsConfigurationResultTypeDef(TypedDict):
    AutoEnable: bool


class OrganizationS3LogsConfigurationTypeDef(TypedDict):
    AutoEnable: bool


class OrganizationTypeDef(TypedDict, total=False):
    Asn: str
    AsnOrg: str
    Isp: str
    Org: str


class OwnerTypeDef(TypedDict, total=False):
    Id: str


class PaginatorConfigTypeDef(TypedDict, total=False):
    MaxItems: int
    PageSize: int
    StartingToken: str


class PermissionConfigurationTypeDef(TypedDict, total=False):
    BucketLevelPermissions: "BucketLevelPermissionsTypeDef"
    AccountLevelPermissions: "AccountLevelPermissionsTypeDef"


class PortProbeActionTypeDef(TypedDict, total=False):
    Blocked: bool
    PortProbeDetails: List["PortProbeDetailTypeDef"]


class PortProbeDetailTypeDef(TypedDict, total=False):
    LocalPortDetails: "LocalPortDetailsTypeDef"
    LocalIpDetails: "LocalIpDetailsTypeDef"
    RemoteIpDetails: "RemoteIpDetailsTypeDef"


class PrivateIpAddressDetailsTypeDef(TypedDict, total=False):
    PrivateDnsName: str
    PrivateIpAddress: str


class ProductCodeTypeDef(TypedDict, total=False):
    Code: str
    ProductType: str


class PublicAccessTypeDef(TypedDict, total=False):
    PermissionConfiguration: "PermissionConfigurationTypeDef"
    EffectivePermission: str


class RemoteIpDetailsTypeDef(TypedDict, total=False):
    City: "CityTypeDef"
    Country: "CountryTypeDef"
    GeoLocation: "GeoLocationTypeDef"
    IpAddressV4: str
    Organization: "OrganizationTypeDef"


class RemotePortDetailsTypeDef(TypedDict, total=False):
    Port: int
    PortName: str


class ResourceTypeDef(TypedDict, total=False):
    AccessKeyDetails: "AccessKeyDetailsTypeDef"
    S3BucketDetails: List["S3BucketDetailTypeDef"]
    InstanceDetails: "InstanceDetailsTypeDef"
    ResourceType: str


S3BucketDetailTypeDef = TypedDict(
    "S3BucketDetailTypeDef",
    {
        "Arn": str,
        "Name": str,
        "Type": str,
        "CreatedAt": datetime,
        "Owner": "OwnerTypeDef",
        "Tags": List["TagTypeDef"],
        "DefaultServerSideEncryption": "DefaultServerSideEncryptionTypeDef",
        "PublicAccess": "PublicAccessTypeDef",
    },
    total=False,
)


class S3LogsConfigurationResultTypeDef(TypedDict):
    Status: DataSourceStatus


class S3LogsConfigurationTypeDef(TypedDict):
    Enable: bool


class SecurityGroupTypeDef(TypedDict, total=False):
    GroupId: str
    GroupName: str


class ServiceTypeDef(TypedDict, total=False):
    Action: "ActionTypeDef"
    Evidence: "EvidenceTypeDef"
    Archived: bool
    Count: int
    DetectorId: str
    EventFirstSeen: str
    EventLastSeen: str
    ResourceRole: str
    ServiceName: str
    UserFeedback: str


class SortCriteriaTypeDef(TypedDict, total=False):
    AttributeName: str
    OrderBy: OrderBy


class StartMonitoringMembersResponseTypeDef(TypedDict):
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class StopMonitoringMembersResponseTypeDef(TypedDict):
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class TagTypeDef(TypedDict, total=False):
    Key: str
    Value: str


class ThreatIntelligenceDetailTypeDef(TypedDict, total=False):
    ThreatListName: str
    ThreatNames: List[str]


class TotalTypeDef(TypedDict, total=False):
    Amount: str
    Unit: str


class UnprocessedAccountTypeDef(TypedDict):
    AccountId: str
    Result: str


class UpdateFilterResponseTypeDef(TypedDict):
    Name: str


class UpdateMemberDetectorsResponseTypeDef(TypedDict):
    UnprocessedAccounts: List["UnprocessedAccountTypeDef"]


class UsageAccountResultTypeDef(TypedDict, total=False):
    AccountId: str
    Total: "TotalTypeDef"


class _RequiredUsageCriteriaTypeDef(TypedDict):
    DataSources: List[DataSource]


class UsageCriteriaTypeDef(_RequiredUsageCriteriaTypeDef, total=False):
    AccountIds: List[str]
    Resources: List[str]


class UsageDataSourceResultTypeDef(TypedDict, total=False):
    DataSource: DataSource
    Total: "TotalTypeDef"


class UsageResourceResultTypeDef(TypedDict, total=False):
    Resource: str
    Total: "TotalTypeDef"


class UsageStatisticsTypeDef(TypedDict, total=False):
    SumByAccount: List["UsageAccountResultTypeDef"]
    SumByDataSource: List["UsageDataSourceResultTypeDef"]
    SumByResource: List["UsageResourceResultTypeDef"]
    TopResources: List["UsageResourceResultTypeDef"]
